@@ -10,7 +10,7 @@ use Test::Assert ':all';
 
 sub test_api {
     my @api = grep { ! /^_/ } @{ Class::Inspector->functions('Test::Mock::Class') };
-    assert_deep_equals( [ qw{
+    assert_deep_equals( [ qw(
         add_mock_constructor
         add_mock_method
         create_mock_anon_class
@@ -20,7 +20,7 @@ sub test_api {
         mock_base_object_role
         mock_constructor_methods_regexp
         mock_ignore_methods_regexp
-    } ], \@api );
+    ) ], \@api );
 };
 
 1;
